@@ -1,9 +1,10 @@
 ## ----setting,include=FALSE----------------------------------------------------
 library(knitr);  library(INLA);  library(fields) 
-inla.setOption(num.threads=1)
+set.seed(123)
+inla.setOption(num.threads="1:1")
 inla.setOption(smtp="taucs")
 opts_chunk$set(message=FALSE, warning=FALSE, tidy=FALSE,
-fig.path="figures/SPDE1d")
+fig.path="SPDE1d-figs/SPDE1d")
 knit_hooks$set(small.mar = function(before, options, envir) {
     if (before) par(mar = c(0.1, 0.1, .1, .1))  # smaller margin on top and right
 })
