@@ -2,6 +2,9 @@
 set.seed(1)
 knitr::opts_chunk$set(echo=TRUE, message=FALSE, warning=FALSE)
 library(INLA)
+set.seed(123)
+inla.setOption(num.threads="1:1")
+inla.setOption(smtp="taucs")
 
 ## ----dat----------------------------------------------------------------------
   dat <- expand.grid(a=0:1, b=0:1, d=0:2) ### three discrete
